import json
import os
import requests
import threading
import time
import sys
import queue
#sys.path.append('/home/pi/gxf/python/spotii')
#sys.path.append('/home/pi/gxf/python/spotii/test_chip_handler')

from .send_result import SendResult
from spotii.define import *



recordId=[None,None,None,None,None]

class WebApi(threading.Thread):
    def __init__(self, *args):             # self, imageFile, image-identifier, queue
        threading.Thread.__init__(self)
        self.imageFile = args[0]
        self.identifier= args[1]
        self.notifyQue = args[2]
        self.client    = args[3]
        self.address   = args[4]
        
        
        self.fileName   = self.imageFile.split('/')[-1]
        keyList         = self.fileName.split('_')
        self.cassetteId = keyList[0]
        self.slotNo     = int(keyList[1])
        self.photoIndex = int(keyList[2])
        self.timeStamp  = int(keyList[3])

#qForGui format: [device_index, retCode, QRcode, message]
        
    def addTest(self):
        service = "/ctestlookspot/addtest?"
        keys = "&testid="+self.cassetteId+ "&place="+self.address[0]+ "&city="+self.address[1]+ "&country="+self.address[2]+"&timestamp="+\
        str(self.timeStamp)+'000'+"&mode=speed"+\
        "&localdate="+time.strftime("%d/%m/%Y",time.localtime(self.timeStamp))+\
        "&localtime="+time.strftime("%H:%M:%S",time.localtime(self.timeStamp))+\
        "&readerserial="+SERIAL_NO
        url = baseUrl+service+self.client+keys
        #print("addtest",url)
        payload  = {}
        headers  = {}
        response = requests.request("POST", url, headers=headers, data=payload)
        
        parsing=json.loads(response.text)
        if parsing[CODE] == RESPONSE_SUCCESS:
            return parsing[RSLT][RCID]
        return None
        

    def uploadImage(self):
        service = "/testimagelookspot/upload?"
        if self.photoIndex == 0:
            imageIndex=self.photoIndex
        else:
            imageIndex=self.photoIndex-1
        keys = "&lstestrecordid="+ str(recordId[self.slotNo])+"&lstestid="+self.cassetteId+"&imageindex="+ str(imageIndex)
        url = baseUrl+service+self.client+keys
        #url = "https://www.locationnow.com/lnservices/ws/testimagelookspot/upload?client=laipac&signature=laipacws&passtoken=1b9f3867298b394a&lstestrecordid=6118&lstestid=La0000888&imageindex=0"
        payload={}
        files=[
          ('uploadimage',(self.fileName,open(self.imageFile,'rb'),'image/jpeg'))
        ]
        headers = {}
        response = requests.request("POST", url, headers=headers, data=payload, files=files)        
        print(response.text)
        
        parsing=json.loads(response.text)
        if parsing[CODE] == RESPONSE_SUCCESS:                            
            self.notifyQue.put([self.slotNo, int(parsing[RSLT][RCODE]), self.cassetteId, parsing[RSLT][MSSG], recordId[self.slotNo]])
        os.remove(self.imageFile)        
        return None

    def run(self):
        if recordId[self.slotNo] == None or self.photoIndex == 0:
            recordId[self.slotNo]=self.addTest()
                        
        if recordId[self.slotNo] == None:
            self.notifyQue.put([self.slotNo, -1, "Retry", "Add test Fail"])
            return
        
        print(recordId)
        self.uploadImage()
    
def sendToApi(imageFile, notifyQue, passToken, address): # uploading imagefile name and test result share same queue, file name is string, test result is a list.
    if type(imageFile) ==str:
        webApi=WebApi(IMG_PATH+imageFile, imageFile.split('.')[0], notifyQue, passToken, address)
        webApi.start()
    else:
        sendResult=SendResult(imageFile, passToken)
        sendResult.start()
    
def sendToApi_test():
    imageFile = "La0000835_0_0_1615836967_20210315153607.jpg"
    notifyQue=queue.Queue()
    passToken = "111111111111"
    sendToApi(imageFile, notifyQue, passToken, ADDRESS)
    
def time_test():
    print(time.gmtime())
    t=time.time()
    print(time.gmtime(t))
    print(time.strftime("%b %d %Y %H:%M:%S", time.gmtime(t)))
    print(time.strftime("%b %d %Y %H:%M:%S", time.localtime(t)))
    print(time.strftime("%d/%m/%Y", time.localtime(t)))
    print(time.strftime("%H:%M:%S", time.localtime(t)))

if __name__ == "__main__":
    #sendToApi_test()
    time_test()



import threading
import time
import queue
import sys
#sys.path.append('/home/pi/gxf/python/spotii')
#sys.path.append('/home/pi/gxf/python/spotii/communication')
#from image_post import post
from .ln_web import sendToApi
from .sign_in import SignIn
from spotii.define import *

class CommunicationThread (threading.Thread):
    def __init__(self, threadID, name, qForCom, qForResult):
        threading.Thread.__init__(self)
        self.threadID = threadID
        self.name = name
        self.qForCom=qForCom
        self.qForResult=qForResult
        
    def aiServer(self):
        while True:
            image=self.qForCom.get()            
            post(image, self.qForResult)
            self.qForCom.task_done()
        
    def webApi(self):
        notifyQue=queue.Queue()
        signIn=SignIn(notifyQue)
        signIn.start()
        
        passToken=''

        notify = notifyQue.get()
        if notify[1] == SIGN_IN_SUCCESS:
            passToken = notify[2]
        print(notify)
        notifyQue.task_done()
        signIn.join()
        print("sign in done")
        
    
        
        while True:
            image=self.qForCom.get()            
            sendToApi(image, self.qForResult, SIGNATURE+'&passtoken='+passToken, ADDRESS)
            self.qForCom.task_done()
        
    def run(self):
        super().run()
        print("communication thread start.")
        #self.aiServer()
        self.webApi()
  
#################### Test ####################
def com_test():
    qForCom=queue.Queue()
    qForResult = queue.Queue()
    com=CommunicationThread(3,"communication",qForCom, qForResult)
    com.start()
    
    time.sleep(2)
    

if __name__ == "__main__":
    com_test()   



import json
import os
import requests
import threading
import time
import sys
import queue
#sys.path.append('/home/pi/gxf/python/spotii')
#sys.path.append('/home/pi/gxf/python/spotii/test_chip_handler')

from spotii.define import *

#baseUrl = "https://www.locationnow.com/lnservices/ws"


# {
#     "code": "0",
#     "description": "error",
#     "result": "The user id or password is wrong."
# }


class SignIn(threading.Thread):
    def __init__(self, *args):             # self, imageFile, image-identifier, queue
        threading.Thread.__init__(self)
        self.notifyQue = args[0]
#qForGui format: [device_index, retCode, QRcode, message]
    def run(self):
        excReason=''
        for i in range(SIGN_IN_RETRY):
            try:
                service = "/signinlookspot?"
                keys = SIGNATURE + '&' +USER
                #url = "https://www.locationnow.com/lnservices/ws/signinlookspot?client=laipac&signature=laipacws&userid=feng.gao@laipac.com&password=123456"
                url = baseUrl+service+keys
                payload  = {}
                headers  = {}
                response = requests.request("POST", url, headers=headers, data=payload)
                print(response.text)
                parsing=json.loads(response.text)
                if parsing[CODE] == RESPONSE_SUCCESS:
                    self.notifyQue.put( [NON_SLOT_INDEX, SIGN_IN_SUCCESS, parsing[RSLT][TKEN], ''] )
                else:
                    self.notifyQue.put( [NON_SLOT_INDEX, SIGN_IN_FAIL,  parsing[CODE], parsing[DESC]] )
                return
            except Exception as e:
                excReason = "signInException"
                print(e)
            time.sleep(5)
            
        else:
            self.notifyQue.put( [NON_SLOT_INDEX, SIGN_IN_FAIL,  excReason, ''] )
            
def signIn_test():
    notifyQue=queue.Queue()
    signIn=SignIn(notifyQue)
    signIn.start()
    
    while True:
        notify = notifyQue.get()
        print(notify)
        notifyQue.task_done()
        time.sleep(0.1)
        if not signIn.is_alive():
            break;
    print("sign in done")
    

if __name__ == "__main__":
    signIn_test()    



POWER_BUTTON_PIN          =3
POWER_BUTTON_HOLD_TIME    =3
DEVICE_POLLING_TIME       =1

TOTAL_SLOTS               =5
I2C_DEVICE                =[0x50,0x51,0x52,0x53,0x54]
I2C_PORT                  =TOTAL_SLOTS

#regular slot index is from 0 to TOTAL_SLOTS-1
NON_SLOT_INDEX            =TOTAL_SLOTS
RESPONSE_SUCCESS   ='1'
RESPONSE_ERROR     ='0'
SIGN_IN_RETRY     =5
SIGN_IN_SUCCESS   =0
SIGN_IN_FAIL      =1


EN_5VCC_PIN          =5
HUB_RST_PIN          =6
FAN_PWM_PIN          =19

I2C_MEM_STATUS       =0
I2C_MEM_LED_1        =3
I2C_MEM_LED_2        =4
I2C_MEM_UV           =5
I2C_MEM_ACK          =21
I2C_MEM_FORCE_READ   =22
I2C_MEM_SYTEM_RESET  =23
I2C_MEM_UID          =24
I2C_MEM_ID           =32+2


DEVICE_STATE_ORIGINAL            = 0x00

DEVICE_STATE_CASSETTE_VALID      = 0xAB
DEVICE_STATE_CASSETTE_POLLED     = 0xAC
DEVICE_STATE_CASSETTE_EMPTY      = 0xF0
DEVICE_STATE_CASSETTE_NO_READY   = 0xF1
DEVICE_STATE_CASSETTE_WRONG      = 0xFF

DEVICE_STATE_SUBSYS_EXCEPTION    = 0xE0
DEVICE_STATE_CAMERA_ERROR        = 0xE1
DEVICE_STATE_TAKING_PHOTO        = 0xE2
DEVICE_STATE_I2C_ERROR           = 0xE3
DEVICE_STATE_EXCEPTION           = 0xE4

CASSETTE_STATUS_FLAG     = 0x80
CASSETTE_STATUS = [
                    DEVICE_STATE_CASSETTE_VALID,
                    DEVICE_STATE_CASSETTE_POLLED,
                    DEVICE_STATE_CASSETTE_EMPTY,
                    DEVICE_STATE_CASSETTE_NO_READY,
                    DEVICE_STATE_CASSETTE_WRONG
                  ]


Positive_test_result         = 0
Negative_test_result         = 1
Cassette_not_found           = 2
Control_area_not_found       = 3
Invalid_image_identifier     = 4
Unexpected_exception         = 5


#  stacked slot index  #
SLOT_STATUS_EMPTY            = 0
SLOT_STATUS_DETECTING        = 1
SLOT_STATUS_WARNING          = 2
SLOT_STATUS_POSITIVE         = 3
SLOT_STATUS_NEGATIVE         = 4
SLOT_STATUS_INVALID          = 5


INVALID_DEVICE_INDEX      =0xFF
#IMG_PATH                  ='/home/pi/gxf/python/spotii/img/'
IMG_PATH                  ='img/'

MAX_CAMERA_RESOLUTION_WIDTH     =1600
MAX_CAMERA_RESOLUTION_HEIGHT    =1200
SAMPLE_PIXELS = [[1,1], [100,100], [200,200]]


PHOTO_TAKING_STOP    = 0xAA

GPA_UNIT = 60
GAP1 = 3*GPA_UNIT+45
#GAP1 = 1*GPA_UNIT
GAP2 = 1*GPA_UNIT
GAP3 = 1*GPA_UNIT
GAP4 = 1*GPA_UNIT
GAP5 = 1*GPA_UNIT

GAP_TAIL = 15
PHOTO_TAKING_GAPS =[GAP1,GAP2,GAP3,GAP4,GAP5]

TIMER_DURATION = GAP1+GAP2+GAP3+GAP4+GAP5+GAP_TAIL

#DETECTING_TIMEOUT = GAP1+GAP2+GAP3+GAP4+GAP5+GAP6+GAP_TAIL

#server response result [0, 1, 'La0012684', 'Negative']
RESULT_SLOT_NUMBER =0
RESULT_ERROR_CODE  =1
RESULT_CASSETTE_ID =2
RESULT_TEXT        =3
RESULT_RECORD_ID   =4


baseUrl = "https://www.look-spot.ca/lsservices/ws"
CODE = 'code'
DESC = 'description'
RSLT = 'result'
TKEN = 'passtoken'
RCID = 'testRecordId'
RCODE= 'retCode'
MSSG = 'message'
ADDRESS =["finch","Toronto","Canada"]


SIGNATURE = "client=laipac&signature=laipacws"
USER      = "userid=feng.gao@laipac.com&password=123456"
SERIAL_NO = "654321"


class A():
    def __init__(self):
        print ('First %s nothing')

class B():
    def __init__(self, value):
        print ('Second %s' % value)

class Log(A, B):
    def __init__(self, b):
        A.__init__(self)
        B.__init__(self, b)

        print ('Log')

x = Log( 2222)



import subprocess
from spotii.define import *
import threading
from gpiozero import Button
#from .takePhoto import takePhoto
powerButton = Button(POWER_BUTTON_PIN,True,None,None,POWER_BUTTON_HOLD_TIME)
def shutDown():
    print("shut down now")
    subprocess.Popen(['shutdown','-h','now'])

class OnOffThread (threading.Thread):
    def __init__(self, threadID, name):
        threading.Thread.__init__(self)
        self.threadID = threadID
        self.name = name

    def run (self):
        powerButton.when_held=shutDown #takePhoto
            



import time
import cv2
import random
from shutil import copyfile
import threading
import sys
import threading
import ntpath
import os


#sys.path.append('/home/pi/gxf/python/spotii')
from spotii.define import *
#sys.path.append('/home/pi/gxf/python/spotii/test_handler')

from .calibration import crop_rotate


def camInstCreate(cameraIndex):
    try:
        device="/dev/video"+str(cameraIndex)
#        print(device)
        camInst=cv2.VideoCapture(device)
        camInst.set(cv2.CAP_PROP_FRAME_WIDTH,  MAX_CAMERA_RESOLUTION_WIDTH)
        camInst.set(cv2.CAP_PROP_FRAME_HEIGHT, MAX_CAMERA_RESOLUTION_HEIGHT)
        return camInst
    except Exception as camErr:
        print("Camera create exception:",camErr)
        return None;
    

camera_sem = threading.Semaphore()
def takePhoto(cameraIndex,qrCode,event):
    rtn = None
    for i in range(5):
        camera_sem.acquire()    
        try:
            cam=camInstCreate(cameraIndex)
            s, img=cam.read()
            if s:
                photo=qrCode+'_'+str(int(time.time())) + '_'+time.strftime('%Y%m%d%H%M%S')+'.jpg'
                
                #path = Path("/here/your/path/file.txt")
                #print ((os.getcwd()).parent.absolute())
                
                #print(os.getcwd())
                imageFile=os.getcwd()+'/'+IMG_PATH+photo
                if crop_rotate(img,imageFile):
                    cam.release()
                    camera_sem.release()
                    rtn=photo
                    break;
            else:
                print("Photo taking failed!",qrCode, time.strftime('%Y%m%d%H%M%S'))
        except cv2.error as cv2Error:
            print("takePhoto cv2 Error: ", cv2Error)
        except Exception as e:
            print("takePhoto Exception: ", e)
    
        if cam !=None:
            cam.release()
        camera_sem.release()            
        event.wait(2)
        if event.isSet():
            break;
    return rtn

class TakePhotoProcedure(threading.Thread):
    def __init__(self, slotIndex, qrCode, camera, qCom, stopTakingPhoto):
        threading.Thread.__init__(self)
        self.slotIndex=slotIndex
        self.qrCode=qrCode
        self.camera = camera
        self.qCom = qCom
       
        self.timerParaIndex = 0
        self.taskStop=False
        self.event=stopTakingPhoto

    def run(self):
        while True:
            begin=time.time()
            self.procedure(self.timerParaIndex)
            end=time.time()
                        
            if self.timerParaIndex < len(PHOTO_TAKING_GAPS):
                delay=PHOTO_TAKING_GAPS[self.timerParaIndex] - (end-begin)
                self.timerParaIndex += 1
                if delay > 0:
                    self.event.wait(delay)                
            else:
                self.timerParaIndex = 0
                break;
            
            if self.event.isSet():
                #print(time.strftime('%Y%m%d%H%M%S'), "got stop command")
                break;
            
    def procedure(self,photoIndex):        
        photoFile=takePhoto(self.camera, self.qrCode+'_'+str(self.slotIndex)+'_'+str(photoIndex), self.event)
        if(photoFile !=None ):
            print(photoFile)
            self.qCom.put(photoFile)
        
   
def takePhoto_test():
    cameraIndex = 6
    qrCode ='8888'
    stopTakingPhoto = threading.Event()
    stopTakingPhoto.set()
    print (takePhoto(cameraIndex,qrCode,stopTakingPhoto) )
    
def takePhotoProcedure_test():
    None
    
    
if __name__ == "__main__":
    takePhoto_test()
          



import threading
import time

#qForGui format: [device_index, state, QRcode, message]
class GuiThread (threading.Thread):
    def __init__(self, threadID, name, qForGui):
        threading.Thread.__init__(self)
        self.threadID = threadID
        self.name = name
        self.qForGui=qForGui
        
    def run (self):
        super().run()
        while True:
            qItem=self.qForGui.get()
            if qItem[2]!='':
                print(qItem, time.strftime('%Y%m%d%H%M%S'))

            self.qForGui.task_done()
                        






import sys
import subprocess
import threading
import time
from .i2c_lib import i2c_device
from .take_photo import takePhoto, TakePhotoProcedure
from datetime import datetime,timezone
from spotii.define import *

# from smbus import SMBus
# import sys
# sys.path.append('/home/pi/gxf/python/spotii')
# sys.path.append('/home/pi/gxf/python/spotii/test_chip_handler')
# import subprocess
# from mythread import MyThread
# import time
# import queue
# import threading
# from i2c_lib import i2c_device
# from take_photo import takePhoto
# from datetime import datetime,timezone
# from define import *

class CassettePolling(threading.Thread):
    def __init__(self, slotIndex, i2c, camera, qResult, qCom, deviceQue):
        threading.Thread.__init__(self)
        self.slotIndex = slotIndex
        self.i2c = i2c
        self.camera = camera
        self.qResult = qResult
        self.qCom = qCom
        self.deviceQue=deviceQue
        self.stopTakingPhoto = threading.Event()
        
        
        self.deviceStatus = DEVICE_STATE_ORIGINAL
        
        self.takePhotoProcedure = None
        
    def stopTakePhotoProcedure(self):
#        print(self.takePhotoProcedure)
        if self.takePhotoProcedure != None and self.takePhotoProcedure.is_alive():
            #print("stop take photo procedure")
            self.stopTakingPhoto.set()
            self.takePhotoProcedure.join()
            self.stopTakingPhoto.clear()
        
    def run(self):
        self.periodPoll()
        while True:
            cmd=self.deviceQue.get()
            if cmd == PHOTO_TAKING_STOP:
                #print("stop command")
                self.stopTakePhotoProcedure()
            self.deviceQue.task_done()
            
#        self.cameraTest(self.index, self.i2c, self.camera)

    def notify(self, item):
        if self.deviceStatus != item[1]:
            self.deviceStatus = item[1]
            if item[1] != DEVICE_STATE_CASSETTE_POLLED:
                self.qResult.put(item)

    def getQr(self):
        try:
            for i in range(5):                
                i2cInstant=i2c_device(self.i2c,I2C_PORT)
                status=i2cInstant.read_data(I2C_MEM_STATUS)|0x80 #There should be bug on daughter board I2c function. sometimes missed bit 7.
                
                if self.slotIndex == 0 and status!=DEVICE_STATE_CASSETTE_POLLED:
                    print(hex(status), time.strftime('%Y%m%d%H%M%S'))
                qrCode=None
                if(status == DEVICE_STATE_CASSETTE_VALID):
                    qr=i2cInstant.read_block_data(I2C_MEM_ID, 9)
                    qrCode=(''.join(chr(x) for x in qr))
                    if not qrCode.isalnum():
                        print(time.strftime('%Y%m%d%H%M%S'), "qrCode crashed", self.slotIndex,qrCode)
                        time.sleep(2)
                        continue
                    break;
                elif status & CASSETTE_STATUS_FLAG == 0:
                    print(time.strftime('%Y%m%d%H%M%S'), "Wrong flag, re-read.", self.slotIndex, hex(status))
                    time.sleep(2)
                    continue
                else:
                    #print("Cassette status:", self.index, hex(status))
                    break;
                    
            #if status != DEVICE_STATE_CASSETTE_POLLED and status in CASSETTE_STATUS:
            if status == DEVICE_STATE_CASSETTE_VALID:
                i2cInstant.write_cmd_arg(I2C_MEM_ACK, status)
                print("Write back ACK")
                
            return status,qrCode
        except Exception as err:
            print("CassettePollingException: ", err)
            return DEVICE_STATE_SUBSYS_EXCEPTION, None        

#     def getPicture_new(self, qr_code):
#         print("slot",self.slotIndex,qr_code)
#         self.notify([self.slotIndex, DEVICE_STATE_TAKING_PHOTO, '', 'Taking photo'])
#         photoFile=takePhoto(self.camera, qr_code+'_'+str(self.slotIndex))
#         if(photoFile !=None ):
#             self.qCom.put(photoFile)


    def deviceDeal(self):  # return [device_slotIndex, state, QRcode, message]
        if self.camera == INVALID_DEVICE_INDEX:
            self.notify([self.slotIndex, DEVICE_STATE_CAMERA_ERROR, '', 'Camera error'])
            return 
        if self.i2c == INVALID_DEVICE_INDEX:
            self.notify([self.slotIndex, DEVICE_STATE_I2C_ERROR, '', 'i2c error'])
            return
        status,qr_code =self.getQr();
        if(status == DEVICE_STATE_CASSETTE_POLLED):
            self.notify( [self.slotIndex, DEVICE_STATE_CASSETTE_POLLED, '', 'no change'])
            return
        elif(status == DEVICE_STATE_CASSETTE_VALID):
            self.notify([self.slotIndex, DEVICE_STATE_TAKING_PHOTO, '', 'Taking photo'])
            self.stopTakePhotoProcedure()
            self.takePhotoProcedure = TakePhotoProcedure(self.slotIndex, qr_code, self.camera, self.qCom, self.stopTakingPhoto)
            self.takePhotoProcedure.start()
        else:
            self.stopTakePhotoProcedure()
            self.notify([self.slotIndex, status, '','Cassette error'])
            
    def periodPoll(self):
        #if self.slotIndex == 0:
        #    print("Period poll", time.strftime('%Y%m%d%H%M%S'))
        self.deviceDeal()
        threading.Timer(DEVICE_POLLING_TIME, self.periodPoll).start()

            
        
    def cameraTest(self):
        photoFile=takePhoto(self.camera, "cameraTest"+'_'+str(self.slotIndex))


if __name__ == "__main__":

    qForGui=queue.Queue()
    qForCom=queue.Queue()

    polling_0= CassettePolling(0, 80, 0, qForGui, qForCom)
    polling_2= CassettePolling(1, 81, 2, qForGui, qForCom)
    polling_4= CassettePolling(2, 82, 4, qForGui, qForCom)
    polling_6= CassettePolling(3, 83, 6, qForGui, qForCom)
    polling_8= CassettePolling(4, 84, 8, qForGui, qForCom)
    polling_0.start()
    polling_2.start()
    polling_4.start()
    polling_6.start()
    polling_8.start()
    
        



import json
import os
import requests
import threading
import time
import sys
import queue
#sys.path.append('/home/pi/gxf/python/spotii')
#sys.path.append('/home/pi/gxf/python/spotii/test_chip_handler')

from spotii.define import *

#baseUrl = "https://www.locationnow.com/lnservices/ws"

class SendResult(threading.Thread):
    def __init__(self, *args):             # self, imageFile, image-identifier, queue
        threading.Thread.__init__(self)
        item = args[0]
        #print("send result args 0",item)
        self.cassetteId= item[RESULT_CASSETTE_ID]
        self.slotNo    = item[RESULT_SLOT_NUMBER]
        self.recordId  = item[RESULT_RECORD_ID]
        if item[RESULT_ERROR_CODE] == Positive_test_result:
            self.result = "Positive"
        else:
            self.result = "Negative"
        
        self.client = args[1]
#qForGui format: [device_index, retCode, QRcode, message]
    def run(self):
        service = "/ctestlookspot/saveresult?"
        
        keys = "&testid="+self.cassetteId +"&lstestrecordid="+self.recordId+"&result="+self.result +"&slots="+str(self.slotNo)        
        url = baseUrl+service+self.client+keys
        #url = "https://www.locationnow.com/lnservices/ws/ctestlookspot/saveresult?client=laipac&signature=laipacws&passtoken=1b9f3867298b394a&testid=La0000888&result=Positive&slots=0"
        #print(url)
        payload={}
        headers = {}
        response = requests.request("POST", url, headers=headers, data=payload)
        print(response.text)
        
def sendResult_test():
    result = [0, 0, "La0000001", "NNN"]
    sendResult=SendResult(result, "client=laipac&signature=laipacws&passtoken=1b9f3867298b394a")
    sendResult.start()
    

if __name__ == "__main__":
    sendResult_test()    



from setuptools import setup, find_packages
# __packages__ = find_packages(
#     where = 'spotii',
# #    include = ['define*',],
# #    exclude = ['additional',]
#     )
# __packages__.append('spotii')
__packages__=['spotii','spotii.guifolder','spotii.communication','spotii.on_off','spotii.test_handler']
print(__packages__)
setup(
    name = "spotii",
    version = "0.0.4",
    description = "a demo",
    author = 'gxf',
    author_email = 'feng.gao@laipac.com',
    url = 'https://github.com/gxfca/gitTest',
    packages = __packages__,
#    package_dir ={"":"spotii"},
    entry_points={
    'console_scripts': [
        'spotii=spotii.__main__:spot_main',
    ],
    },
    )



from gpiozero import Button
from gpiozero import LED
import time

import sys
# sys.path.append('/home/pi/gxf/python/spotii')
# sys.path.append('/home/pi/gxf/python/spotii/on_off')

from spotii.define import *


#powerButton = Button(define.POWER_BUTTON_PIN,True,None,None,define.POWER_BUTTON_HOLD_TIME)

if __name__ == "__main__":

    hub_reset=LED(HUB_RST_PIN)
    hub_reset.off()
    time.sleep(0.001)
    hub_reset.on()
    
    



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'main_skeleton.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.
import sys
import os
import queue
import threading
import time

from datetime import datetime,timezone

from PyQt5 import Qt, QtCore, QtGui, QtWidgets
from PyQt5.QtWidgets import QDialog
from PyQt5.QtGui import QFont


from spotii.define import *

#from spotii.gui.gui import GuiThre
#import guifolder
from spotii.communication.communication import CommunicationThread
from spotii.on_off.on_off import OnOffThread
from spotii.test_handler.test_chip_handler import TestChipHandlerThread


class EmitThread(QtCore.QThread):

    signal= QtCore.pyqtSignal(object)

    def __init__(self, sharedQue):
        QtCore.QThread.__init__(self)
        self.qForGui=sharedQue

    def run(self):
        print("Start emit thread")
        while True:
            qItem=self.qForGui.get()
            self.signal.emit(qItem)
            self.qForGui.task_done()

def expendingPolicy(widget):
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(widget.sizePolicy().hasHeightForWidth())
        widget.setSizePolicy(sizePolicy)

def minPolicy(widget):
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(widget.sizePolicy().hasHeightForWidth())
        widget.setSizePolicy(sizePolicy)
def preferPolicy(widget):
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(widget.sizePolicy().hasHeightForWidth())
        widget.setSizePolicy(sizePolicy)

def minExpending(widget):
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(widget.sizePolicy().hasHeightForWidth())
        widget.setSizePolicy(sizePolicy)

class MyToolButton(QtWidgets.QToolButton):
    def __init__(self, parent, activeIcon, inactiveIcon):
        super(MyToolButton,self).__init__(parent)
        self.activeIcon=activeIcon
        self.inactiveIcon=inactiveIcon
    def enterEvent(self, event):
##        print("Mouse entered")
##        self.setStyleSheet("QToolButton{background-color: rgba(0,21,59,255);}")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(self.activeIcon), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.setIcon(icon)
        self.repaint()
        # emit your signal
    def leaveEvent(self, event):
##        print("Mouse left")
##        self.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}")
        if self.isChecked():
            return
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(self.inactiveIcon), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.setIcon(icon)
        self.repaint()

class UnpressedToolButton(QtWidgets.QToolButton):
    def mousePressEvent(self, event):
        pass

class MyDialog(QDialog):
    def __init__(self,parent = None):
        super(MyDialog, self).__init__(parent)
        try:
            print("is modal?",self.isModal())
            self.setModal(True)
            print("Set modal", self.isModal())
        except:
            print("error in myDialog init")
        #self.setGeometry(100,100,500,200)
    def closeEvent(self,event):
        print("Dialog closed")
##        quit_msg = "Are you sure you want to exit the dialog?"
##        reply = QtGui.QMessageBox.question(self, 'Message', 
##                        quit_msg, QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
##        if reply == QtGui.QMessageBox.Yes:
##            event.accept()
##        else:
##            event.ignore()

    def grabMouse():
        print("grabMouse")
    
    def eventFilter(self, source, event):

        try:
            
 
            if event.type() == QtCore.QEvent.FocusIn: #and source is self.ledit_corteA:
                print("FocusIn")
            elif event.type() == QtCore.QEvent.FocusOut:
                print("FocusOut")
            elif event.type() == QtCore.QEvent.GrabMouse:
                print("GrabMouse")
            elif event.type() == QtCore.QEvent.HoverEnter:
                print("HoverEnter")
            elif event.type() == QtCore.QEvent.HoverLeave:
                print("HoverLeave")
            elif event.type() == QtCore.QEvent.HoverMove:
                print("HoverMove")
            elif event.type() == QtCore.QEvent.MouseButtonRelease:
                print("MouseButtonRelease")
            elif event.type() == QtCore.QEvent.MouseTrackingChange:
                print("MouseTrackingChange")
            elif event.type() == QtCore.QEvent.MouseButtonPress: #and source is self.ledit_corteB:
                print("MouseButtonPress")
            elif event.type() == QtCore.QEvent.MouseMove:
                print("MouseMove")
            elif event.type() == QtCore.QEvent.CursorChange:
                print("CursorChange")
            elif event.type() == QtCore.QEvent.Enter:
                print("Enter")
            elif event.type() == QtCore.QEvent.Leave:
                print("Leave")
            elif event.type() == QtCore.QEvent.GraphicsSceneHoverMove:
                print("GraphicsSceneHoverMove")
            elif event.type() == QtCore.QEvent.GraphicsSceneMouseMove:
                print("GraphicsSceneMouseMove")
            elif event.type() == QtCore.QEvent.GraphicsSceneHoverEnter:
                print("GraphicsSceneHoverEnter")
            elif event.type() == QtCore.QEvent.WindowDeactivate:
                print("WindowDeactivate")
            elif event.type() == QtCore.QEvent.NonClientAreaMouseButtonPress:
                print("NonClientAreaMouseButtonPress")
            elif event.type() == QtCore.QEvent.NonClientAreaMouseMove:
                print("NonClientAreaMouseMove")
            else:
                print("Other")
        except:
            print("error in eventFilter")
        return super(MyDialog, self).eventFilter(source, event)
        

class MyLabel(QtWidgets.QLabel):
    def eventFilter(self, source, event):

        try:
            print("in MyLabel")
        except:
            print("error in MyLabel eventFilter")
        return super(MyLabel, self).eventFilter(source, event)
        


#PNG_FOLDER = "./gui/png/"
LOCAL_PNG_FOLDER = "guifolder/png/"
class Ui_Title():
    def __init__(self, centralwidget, parentLayOut):
        
        PNG_FOLDER = os.getcwd()+'/'+LOCAL_PNG_FOLDER
        
#        self.backGround = QtWidgets.QLabel(centralwidget)
        self.backGround = MyLabel(centralwidget)
        
        self.backGround.setObjectName("BackGround")

        self.backGround.setPixmap(QtGui.QPixmap(PNG_FOLDER+"title/rectangle.png"))
        self.backGround.setScaledContents(True)
#        minPolicy(self.backGround)


#        self.backGround.installEventFilter(self.backGround)
        
        parentLayOut.addWidget(self.backGround)

        hLayout = QtWidgets.QHBoxLayout(self.backGround)
        hLayout.setObjectName("titleLayout")
        hLayout.setSpacing(10)
        hLayout.setContentsMargins(0, 0, 10, 0)
        
        self.iconButton(self.backGround,hLayout, "Logo", 135, 27, PNG_FOLDER+"title/logo.png", PNG_FOLDER+"title/logo.png")

        hLayout.addStretch(1)
        self.iconButton(self.backGround,hLayout, "Help", 24, 18,
                        PNG_FOLDER+"title/spot-icons-help-active.png",
                        PNG_FOLDER+"title/spot-icons-help-inactive.png",
                        self.clickHook)
        
        self.iconButton(self.backGround,hLayout, "Bluetooth", 24, 18,
                        PNG_FOLDER+"title/spot-icons-bluetooth-active.png",
                        PNG_FOLDER+"title/spot-icons-bluetooth-inactive.png",
                        self.clickHook)
        
        self.iconButton(self.backGround,hLayout, "Wifi", 24, 18,
                        PNG_FOLDER+"title/spot-icons-wifi-active.png",
                        PNG_FOLDER+"title/spot-icons-wifi-inactive.png",
                        self.clickHook)
        
        self.iconButton(self.backGround,hLayout, "Sound", 24, 18,
                        PNG_FOLDER+"title/spot-icons-sound-active.png",
                        PNG_FOLDER+"title/spot-icons-sound-inactive.png",
                        self.clickHook)
        
        self.iconButton(self.backGround,hLayout, "Calendar", 24, 18,
                        PNG_FOLDER+"title/spot-icons-calendar-active.png",
                        PNG_FOLDER+"title/spot-icons-calendar-inactive.png",
                        self.clickHook)
        
        self.iconButton(self.backGround,hLayout, "Setting", 24, 18,
                        PNG_FOLDER+"title/spot-icons-settings-inactive.png",
                        PNG_FOLDER+"title/spot-icons-settings-inactive.png",
                        self.clickHook)
        
    def iconButton(self, parent, layout, name, width, height, pixMap ,pixMapInactive, hook=None):
#        toolButton = QtWidgets.QToolButton(parent)
        if( hook == None):
            toolButton = UnpressedToolButton(parent)
        else:
            toolButton = MyToolButton(parent,pixMap,pixMapInactive)
            toolButton.clicked.connect(hook)
            toolButton.setCheckable(True)
        toolButton.setAutoFillBackground(True)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(pixMapInactive), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        toolButton.setIcon(icon)
        toolButton.setIconSize(QtCore.QSize(width, height))
#        toolButton.repaint()
        toolButton.setObjectName(name)
        toolButton.setStyleSheet("QToolButton{background-color: transparent; border:0; color : white}");
        toolButton.setAutoRaise(True)

        
        layout.addWidget(toolButton)

##    def clickHook(self):
##        print("in clickHook")
        
    def clickHook(self):
#        dlg = MyDialog(self.backGround)
        dlg = MyDialog()
        dlg.setWindowTitle("HELLO!")
        dlg.installEventFilter(dlg)
        dlg.exec_()
        
##        dialog = QtWidgets.QDialog(self.backGround)
##        dialog.ui = Form()
##        dialog.ui.setupUi(dialog)
##        dialog.exec_()
##        dialog.show()        


class Ui_Slot():    
    def __init__(self, centralwidget, parentLayOut, slot):
        PNG_FOLDER = os.getcwd()+'/'+LOCAL_PNG_FOLDER
        self.stackedLayout_slot = QtWidgets.QStackedLayout()
        self.stackedLayout_slot.setObjectName("stackedLayout_slot")
        
        self.slotItem(centralwidget, self.stackedLayout_slot, "Empty",       PNG_FOLDER+"slot/spot-slot-empty.png")
        self.slotItem(centralwidget, self.stackedLayout_slot, "Detecting",   PNG_FOLDER+"slot/detecting/detecting "+str(slot)+".png")
        self.slotItem(centralwidget, self.stackedLayout_slot, "Warning",     PNG_FOLDER+"slot/warning/warning - "+str(slot)+".png")
        self.slotItem(centralwidget, self.stackedLayout_slot, "Positive",    PNG_FOLDER+"slot/positive/detecting - positive "+str(slot)+".png")
        self.slotItem(centralwidget, self.stackedLayout_slot, "Negative",    PNG_FOLDER+"slot/negative/negative - "+str(slot)+".png")
        self.slotItem(centralwidget, self.stackedLayout_slot, "Invalid",     PNG_FOLDER+"slot/invalid/invalid - "+str(slot)+".png")
                        
        parentLayOut.addLayout(self.stackedLayout_slot)
#        self.sdfsfsdfs.start(1000)
        self.cassetteId=""
        self.timeLeft = TIMER_DURATION
        self.myTimer = QtCore.QTimer()
        self.myTimer.timeout.connect(self.timer_timeout)
        
    def textButton(self, parent, layout,name, font=None):
        if font == None:
            font = QtGui.QFont()
            font.setPointSize(10)
            font.setBold(True)
        button = QtWidgets.QPushButton(parent)
        button.setFont(font)
        button.setObjectName(name)
        button.setStyleSheet("QPushButton{background-color: transparent; border:0; color : white}");
        button.setFocusPolicy(QtCore.Qt.NoFocus)
        layout.addWidget(button)

    def slotItem(self, centralwidget, parent, name, pixMap):
        label = QtWidgets.QLabel(centralwidget)
        label.setObjectName(name)
#        label.setStyleSheet(".QLabel{border-image:url("+pixMap+");}")
        label.setPixmap(QtGui.QPixmap(pixMap))
        label.setScaledContents(True)
#        expendingPolicy(label)
        
        vLayout = QtWidgets.QVBoxLayout(label)
        vLayout.setObjectName("slotLayout")
        vLayout.setSpacing(51)
        vLayout.setContentsMargins(0, 133, 0, 0)
        
        self.textButton(label,vLayout, "Button Time")
        self.textButton(label,vLayout, "Button Text")                    
        parent.addWidget(label)
       
    def setStatus(self, status_index, cassette, time=None):
        
        self.cassetteId=cassette
        self.stackedLayout_slot.setCurrentIndex(status_index)
        item=self.stackedLayout_slot.currentWidget()
        item.layout().itemAt(1).widget().setText(self.cassetteId) ## 1 for cassette ID
        if(time!=None):
            item.layout().itemAt(0).widget().setText(time) ## 0 for counting down timer
        else:
            self.myTimer.stop()

    def detecting(self, cassette):
        
        self.cassetteId=cassette
        self.timeLeft = TIMER_DURATION
        self.myTimer.start(1000)
#         try:
#             self.sdfsfsdfs.start(1000)
#         except:
#             print("error--testing")
        self.showDetecting()

    def timer_timeout(self):
        self.timeLeft -= 1
#        print(" in timer_timeout()")
        self.showDetecting()        
        if self.timeLeft == 0:
            self.detection_timeout()
            self.myTimer.stop()
        
    def showDetecting(self):
        self.setStatus(SLOT_STATUS_DETECTING, self.cassetteId, time.strftime('%M:%S', time.gmtime(self.timeLeft)))
            
    def detection_timeout(self):
        self.setStatus(SLOT_STATUS_WARNING, self.cassetteId)        
 
class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(480, 272)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        MainWindow.setCentralWidget(self.centralwidget)
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName("gridLayout")
        
        self.gridLayout.setContentsMargins(0, 0, 0, 0)####        

        self.verticalLayout_main = QtWidgets.QVBoxLayout()
        self.verticalLayout_main.setObjectName("verticalLayout_main")
        self.verticalLayout_main.setSpacing(0)
        self.gridLayout.addLayout(self.verticalLayout_main, 0, 0, 1, 1)

        self.horizontalLayout_title = QtWidgets.QHBoxLayout()
        self.horizontalLayout_title.setObjectName("horizontalLayout_title")
        self.horizontalLayout_slots = QtWidgets.QHBoxLayout()
        self.horizontalLayout_slots.setObjectName("horizontalLayout_slots")
        self.horizontalLayout_slots.setSpacing(0)
        self.verticalLayout_main.addLayout(self.horizontalLayout_title)
        self.verticalLayout_main.addLayout(self.horizontalLayout_slots)
        
        self.title=Ui_Title(self.centralwidget, self.horizontalLayout_title)
        self.slot=[]
        for i in range(5):
            self.slot.append(Ui_Slot(self.centralwidget, self.horizontalLayout_slots, i+1))
#         self.slot_1=Ui_Slot(self.centralwidget, self.horizontalLayout_slots, 1)
#         self.slot_2=Ui_Slot(self.centralwidget, self.horizontalLayout_slots, 2)
#         self.slot_3=Ui_Slot(self.centralwidget, self.horizontalLayout_slots, 3)
#         self.slot_4=Ui_Slot(self.centralwidget, self.horizontalLayout_slots, 4)
#         self.slot_5=Ui_Slot(self.centralwidget, self.horizontalLayout_slots, 5)
#        self.showState(1,"hello")

        
        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

        self.detecting=False;
    def showState(self, status_index,item): # for testing and debugging purpose
        for i in range(5):
            self.slot[i].setStatus(status_index,item)
            
#         self.slot_1.setIndex(index,item)
#         self.slot_2.setIndex(index,item)
#         self.slot_3.setIndex(index,item)
#         self.slot_4.setIndex(index,item)
#         self.slot_5.setIndex(index,item)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))

    def setQue(self,queue):
        self.queMonitor=EmitThread(queue)
        self.queMonitor.signal.connect(self.emitHook)
        self.queMonitor.start()
        

    def emitHook(self,item):
        print(time.strftime('%Y%m%d%H%M%S'),"emitHook:",item)
        slotNo  = item[0]
        errCode = item[1]
        qrCode  = item[2]
        
        if slotNo == NON_SLOT_INDEX:
            for i in range(TOTAL_SLOTS):
                self.slot[i].setStatus(SLOT_STATUS_WARNING, qrCode)
            
        elif errCode == DEVICE_STATE_TAKING_PHOTO:
            self.slot[item[0]].detecting(qrCode)
        elif errCode == Positive_test_result:
            self.slot[item[0]].setStatus(SLOT_STATUS_POSITIVE, qrCode)
        elif errCode == Negative_test_result:
            self.slot[item[0]].setStatus(SLOT_STATUS_NEGATIVE, qrCode)
        elif errCode == Invalid_image_identifier:
            self.slot[item[0]].setStatus(SLOT_STATUS_INVALID, qrCode)
        elif errCode == DEVICE_STATE_CASSETTE_EMPTY:
            self.slot[item[0]].setStatus(SLOT_STATUS_EMPTY, qrCode)
        else:
            self.slot[item[0]].setStatus(SLOT_STATUS_WARNING, qrCode)
            
        
#         self.slot_1.setIndex(1,"La0000107",item) #show index 1 label and cassette ID is "La0000107", with counting down timer on slot 1
#         if not self.detecting:
#             print("set slot 2 detecting")
#             self.slot_2.detecting("La0000100")
#             self.detecting=True
# ##        self.slot_2.setIndex(2,"La0000107")
#         self.slot_3.setIndex(3,"La0000107",item)
#         self.slot_4.setIndex(4,"La0000107")
#         self.slot_5.setIndex(5,"La0000107",item)
        

TEST_DURATION = 0
class PeriodQueThread (threading.Thread):
    def __init__(self, queue, interval):
        threading.Thread.__init__(self)
        self.queue=queue
        self.interval = interval
    def run (self):
        duration=0
        while True:
            self.queue.put(time.strftime("%H:%M:%S"))
            time.sleep(self.interval)
            duration +=1
            if duration == TEST_DURATION:
                break;


def guiTest():
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()

#@setWindowFlags(Qt::FramelessWindowHint | Qt::Popup);@
    
#     flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.WindowStaysOnTopHint)
#     MainWindow.setWindowFlags(flags)
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)


    qForGui=queue.Queue()
    ui.setQue(qForGui)

    testQue =PeriodQueThread(qForGui,1)
    testQue.start()
    
    MainWindow.show()
    sys.exit(app.exec_())


def gui(qForGui):
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
#     flags = QtCore.Qt.WindowFlags(QtCore.Qt.FramelessWindowHint | QtCore.Qt.WindowStaysOnTopHint)
#     MainWindow.setWindowFlags(flags)
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    ui.setQue(qForGui)
    MainWindow.show()
    sys.exit(app.exec_())

def spot_main():

    qForGui=queue.Queue()
    qForCom=queue.Queue()
    qForResult=queue.Queue()
#    GUI        =GuiThread(1,"GUI",qForGui)
    Comm       =CommunicationThread(2,"Comm",qForCom, qForResult)
    TestMonitor=TestChipHandlerThread(3,"TCH",qForCom, qForGui, qForResult)
    OnOff      =OnOffThread(4,"OnOff")

#    GUI.start()
    Comm.start()
    OnOff.start()
    TestMonitor.start()
    gui(qForGui)
#     GUI.join()
#     Comm.join()
#     OnOff.join()
#     TestMonitor.join()
    

if __name__ == "__main__":
#    gui()
#    guiTest()
    print(__file__)

    spot_main()
    